pub struct BufferedUartTx<'d> { /* private fields */ }Expand description
Tx-only buffered UART
Created with BufferedUart::split
Implementations
Sourceimpl<'d> BufferedUartTx<'d>
impl<'d> BufferedUartTx<'d>
Sourcepub async fn write(&mut self, buf: &[u8]) -> Result<usize, Error>
pub async fn write(&mut self, buf: &[u8]) -> Result<usize, Error>
Write to the TX buffer, waiting until there is space for at least one byte.
Returns the number of bytes written, which is at least 1 if buf is not empty.
Sourcepub async fn flush(&mut self) -> Result<(), Error>
pub async fn flush(&mut self) -> Result<(), Error>
Wait until the TX buffer is empty and the last byte has been transmitted.
Sourcepub fn blocking_write(&mut self, buf: &[u8]) -> Result<usize, Error>
pub fn blocking_write(&mut self, buf: &[u8]) -> Result<usize, Error>
Write to the TX buffer, busy-waiting until there is space for at least one byte.
Returns the number of bytes written, which is at least 1 if buf is not empty.
Sourcepub fn blocking_flush(&mut self) -> Result<(), Error>
pub fn blocking_flush(&mut self) -> Result<(), Error>
Busy-wait until the TX buffer is empty and the last byte has been transmitted.
Sourcepub fn write_ready(&mut self) -> Result<bool, Error>
pub fn write_ready(&mut self) -> Result<bool, Error>
Return whether the TX buffer has space, so that a write would not wait.
Sourcepub fn set_config(&mut self, config: &Config) -> Result<(), ConfigError>
pub fn set_config(&mut self, config: &Config) -> Result<(), ConfigError>
Reconfigure the driver
Sourcepub fn send_break(&self)
pub fn send_break(&self)
Send break character
Sourcepub fn set_baudrate(&self, baudrate: u32) -> Result<(), ConfigError>
pub fn set_baudrate(&self, baudrate: u32) -> Result<(), ConfigError>
Set baudrate